<?php

namespace Sukellos\Admin;

use Sukellos\Email_Tracker_Url_Manager;
use Sukellos\WP_Sukellos_Email_Tracker_Loader;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\Singleton;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 *
 * @since 1.0.0
 */
class WP_Sukellos_Add_Email_Tracked_Url_Admin extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();

        /**
         * Action : sukellos_fw/admin_builder/item_form/fields_submitted_{form_item_id}
         * Called after the fields are submitted only if mandatories verified in form item
         */
        add_action( 'sukellos_fw/admin_builder/item_form/fields_submitted_'.WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param().'_form_add_tracked_url', array( $this, 'action_item_form_fields_submitted' ) );

    }

    /**
     * Process the form submitted on itself
     * @return string the notice
     */
    public function action_item_form_fields_submitted() {

        WP_Log::debug( __METHOD__, ['POST'=>$_POST], 'wp-sukellos-fw');

        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();

        $tracked_url = $_POST[ $options_suffix_param.'_tracked_url' ];
        $number_emails_sent = $_POST[ $options_suffix_param . '_add_number_emails_sent' ];
        $name = $_POST[ $options_suffix_param . '_add_name' ];
        $description = $_POST[ $options_suffix_param . '_add_description' ];

        // Add tracking
        Email_Tracker_Url_Manager::instance()->generate_tracking_url( $tracked_url, $number_emails_sent, $name, $description );
    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */

    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {}

    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items() {

        // To improve code readability
        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();
        WP_Log::debug( __METHOD__, ['$options_suffix_param'=>$options_suffix_param, 'GET' => $_GET], 'wp-sukellos-fw');

        // Admin page.
        $page_id = $options_suffix_param.'_add_email_tracked_url_admin_page';

        //
        // Page creation
        //
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => __( 'Add tracked URL', 'wp-sukellos-fw' ),
                'title' => __( 'Add tracked URL', 'wp-sukellos-fw' ),
                'id' => $page_id, // Unique ID of the menu item
                'capability' => 'manage_options', // User role
                'parent_id' => $options_suffix_param.'_admin_page', // id of parent, if null, then this is a top level menu
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 3, // Menu position. Can be used for both top and sub level menus
                'use_tabs' => false,
                'desc' => __( 'Allow to add tracked URL', 'wp-sukellos-fw' )
            )
        );

        // Create a note
        $form = $admin_page->create_form(
            array(
                'id' => $options_suffix_param . '_form_add_tracked_url',
                'name' => __( 'Form used to add tracked URL', 'wp-sukellos-fw' ),
                'desc' =>__( 'Form used to add tracked URL', 'wp-sukellos-fw' ),
                'use_reset' => false,
                'save' => __( 'Add', 'wp-sukellos-fw' ),
            )
        );

        // Create a URL  field
        $form->create_form_field(
            array(
                'type' => Item_type::TEXT,
                'id' => $options_suffix_param.'_tracked_url',
                'name' => __( 'Tracked URL', 'wp-sukellos-fw' ),
                'desc' => __( 'URL to be tracked.', 'wp-sukellos-fw' ),
                'default' => '',
                'hidden' => false,
                'mandatory' => __( 'Please type an URL to be tracked.', 'wp-sukellos-fw' ),
            )
        );

        // Create a URL  field
        $form->create_form_field(
            array(
                'type' => Item_type::TEXT,
                'id' => $options_suffix_param.'_add_name',
                'name' => __( 'Name', 'wp-sukellos-fw' ),
                'desc' => __( 'Name of the campaign.', 'wp-sukellos-fw' ),
                'default' => '',
                'hidden' => false,
                'mandatory' => __( 'Please type a name for the campaign to be tracked.', 'wp-sukellos-fw' ),
            )
        );

        // Create a URL  field
        $form->create_form_field(
            array(
                'type' => Item_type::TEXTAREA,
                'id' => $options_suffix_param.'_add_description',
                'name' => __( 'Description', 'wp-sukellos-fw' ),
                'desc' => __( 'Description of the campaign.', 'wp-sukellos-fw' ),
                'default' => '',
                'hidden' => false,
            )
        );

        // Create a URL  field
        $form->create_form_field(
            array(
                'type' => Item_type::NUMBER,
                'id' => $options_suffix_param . '_add_number_emails_sent',
                'name' => 'Number',
                'desc' => __( 'Estimated number of emails to be sent containing the tracked URL.', 'wp-sukellos-fw' ),
                'default' => 0,
                'css' => '',
                'hidden' => false,
                // Specific
                'size' => 'medium', // or medium or large
                'placeholder' => '', // show this when blank
                'min' => 0, // Minimum value, default 0
                'max' => 1000000, // Maximum value, default 1000
                'step' => 1, // Step, default 1
                'unit' => 'emails', // Unit, added after the slider for information, default ''
            )
        );
    }

}