<?php

namespace Sukellos\Admin;

use Sukellos\Email_Tracked_Url_List_Table;
use Sukellos\WP_Sukellos_Email_Tracker_Loader;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\Singleton;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 *
 * @since 1.0.0
 */
class WP_Sukellos_Email_Tracked_Urls_Admin extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();

        // TIPS: Allow to add content that can be treated only after admin_menu hook execution context
        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();
        add_filter( 'sukellos_fw/admin_builder/field/'.$options_suffix_param.'_content_email_tracked_urls', array( $this, 'filter_field_content_email_tracked_urls' ), 10 ,1 );
    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */

    /**
     * Allow to add content that can be treated only after admin_menu hook execution context
     *
     * @param $content content that can be enriched
     * @return mixed
     *
     * @since 1.3.2
     */
    public function filter_field_content_email_tracked_urls( $content ) {

        WP_Log::debug( __METHOD__, ['$content'=>$content, '$_POST'=>$_POST], 'wp-sukellos-fw');

        // Create a List Table
        $list_table = new Email_Tracked_Url_List_Table();
        $list_table->prepare_items();

        ob_start();
        $list_table->display_result_message();

        echo '
            <form method="post">
                <input type="hidden" name="page" value="'.WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param().'_email_tracked_urls_admin_page'.'">';

        $list_table->search_box('search', 'search_id');
        $list_table->display();

        wp_nonce_field('bulk-skemailtracker-url-target-list');
        echo '
            </form>
        ';
        $html_content = ob_get_clean();

        return $html_content;
    }

    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {}

    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items() {

        // To improve code readability
        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();
        WP_Log::debug( __METHOD__, ['$options_suffix_param'=>$options_suffix_param, 'GET' => $_GET], 'wp-sukellos-fw');

        // Admin page.
        $page_id = $options_suffix_param.'_email_tracked_urls_admin_page';

        //
        // Page creation
        //
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => __( 'Tracked URLs', 'wp-sukellos-fw' ),
                'title' => __( 'Tracked URLs', 'wp-sukellos-fw' ),
                'id' => $page_id, // Unique ID of the menu item
                'capability' => 'manage_options', // User role
                'parent_id' => $options_suffix_param.'_admin_page', // id of parent, if null, then this is a top level menu
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 2, // Menu position. Can be used for both top and sub level menus
                'use_tabs' => false,
                'desc' => __( 'Allow to add tracked URL', 'wp-sukellos-fw' )
            )
        );

        // This content will be filled by its self filter: sukellos_fw/admin_builder/field/'.WP_ATI3D_Licences_Loader::instance()->get_options_suffix_param().'_content_request_logs
        // TIPS: Allow to add content that can be treated only after admin_menu hook execution context
        $admin_page->create_content(
            array(
                'id' => $options_suffix_param . '_content_email_tracked_urls',
                'name' => __( 'Tracked URLs', 'wp-sukellos-fw' ),
                'content' => '',
            )
        );
    }

}