<?php

namespace Sukellos\Admin;

use Sukellos\WP_Sukellos_Email_Tracker_Loader;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\Singleton;
use Sukellos\WPFw\WP_Plugin_Admin;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 * Main admin is used as controller to init admin menu and all other admin pages
 *
 * @since 1.0.0
 */
class WP_Sukellos_Email_Tracker_Admin extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();
    }


    /**
     * Get sub admin instances.
     * Must be used ONLY in main admin, to init sub admin instances correctly
     *
     * @return array of WP_Plugin_Admin instances
     */
    public function get_plugin_sub_admins() {

        if ( !is_user_logged_in() || !is_admin() ) {

            return array();
        }

        $admin_array = array(
            WP_Sukellos_Add_Email_Tracked_Url_Admin::instance(),
            WP_Sukellos_Email_Tracked_Urls_Admin::instance(),
            WP_Sukellos_Email_Tracked_Url_Detail_Admin::instance(),
            WP_Sukellos_Email_Tracked_Url_Edit_Admin::instance(),
        );

        return $admin_array;
    }

    /**
     * Gets the plugin configuration URL
     * This is used to build actions list in plugins page
     * Leave blank ('') to disable
     *
     * @since 1.0.0
     *
     * @return string plugin settings URL
     */
    public function get_settings_url() {

        return admin_url( 'admin.php?page='.WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param().'_admin_page' );
    }

    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {

        // CSS
        wp_enqueue_style('sukellos_email_tracker_admin_css', WP_Sukellos_Email_Tracker_Loader::instance()->get_plugin_dir_url().'assets/css/admin.css', array(), '1.0', 'all');

        // JS
        wp_enqueue_script('sukellos_email_tracker_admin_js', WP_Sukellos_Email_Tracker_Loader::instance()->get_plugin_dir_url().'assets/js/admin.js', array('jquery'), '1.0', true);
    }
   
    /***
     * Admin page
     */
    public function create_items() {

        // Admin page.
        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => WP_Sukellos_Email_Tracker_Loader::instance()->get_name(),
                'title' => WP_Sukellos_Email_Tracker_Loader::instance()->get_name(),
                'id' => $options_suffix_param.'_admin_page',
                'capability' => 'manage_options',
                'parent_id' => null,
                'icon' => 'dashicons-smiley',
                'position' => 12,
                'desc' => __( 'Targeted Results: Accurate Clicks, Knowledgeable Engagement Reporting' , 'wp-sukellos-fw' ),
            )
        );

        ob_start();
        ?>

        <div class="tracking-url-tuto-container">
            <h2><?php echo __('Description', 'wp-sukellos-fw'); ?></h2>

            <p><?php echo __('This WordPress plugin offers robust tracking of email opens and link clicks, providing detailed statistics on user interactions.', 'wp-sukellos-fw'); ?></p>

            <p><?php echo __('It supports segmented tracking, allowing you to categorize and monitor different email campaigns or user groups. Additionally, the plugin can enrich clicked links with dynamic parameters, such as the recipient\'s name and email, making it a perfect fit for mass email tools that personalize messages through merge fields, commonly used in CRMs.', 'wp-sukellos-fw'); ?></p>

            <p><?php echo __('The plugin gives you insightful data on engagement, helping optimize email marketing strategies.', 'wp-sukellos-fw'); ?></p>

            <h2><?php echo __('How the tracking works', 'wp-sukellos-fw'); ?></h2>

            <h3><?php echo __('Email Open Tracking (Image Pixel)', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('The plugin generates a unique tracking pixel—a tiny 1x1 invisible image—specifically for tracking email opens. When this pixel is loaded within an email, it signals that the recipient has opened the email. Here\'s how you can use the image pixel:', 'wp-sukellos-fw'); ?></p>

            <div class="code-block">
                &lt;img src="https://yourdomain.com/wp-json/suket/email_open/?token=UNIQUE_TOKEN" width="1" height="1" style="display:none;" alt=""&gt;
            </div>

            <p><?php echo __('This pixel should be inserted into the body of the email. When the recipient opens the email and allows images to be displayed, the server captures the event.', 'wp-sukellos-fw'); ?></p>

            <p><strong><?php echo __('Limitations:', 'wp-sukellos-fw'); ?></strong> <?php echo __('Some email clients block images by default, meaning the pixel won\'t always fire unless the user manually allows image loading. In such cases, you can rely on the click tracking explained below.', 'wp-sukellos-fw'); ?></p>

            <h3><?php echo __('Link Click Tracking', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('The plugin generates a trackable link. When a recipient clicks on the link, it first passes through your server, where the click is registered, before redirecting the recipient to the final destination.', 'wp-sukellos-fw'); ?></p>

            <p><strong><?php echo __('How to construct the tracking link:', 'wp-sukellos-fw'); ?></strong></p>
            <div class="code-block">
                https://yourdomain.com/wp-json/suket/link_click/?token=UNIQUE_TOKEN
            </div>

            <p><?php echo __('This link must replace the original target URL in your email or web content. When clicked, it registers the event and redirects the user to the target page.', 'wp-sukellos-fw'); ?></p>

            <h3><?php echo __('Constructing the HTML anchor (&lt;a href=...&gt;) for the tracking link:', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('To insert the tracking link into your content, you need to create an anchor tag:', 'wp-sukellos-fw'); ?></p>
            <div class="code-block">
                &lt;a href="https://yourdomain.com/wp-json/suket/link_click/?token=UNIQUE_TOKEN"&gt;<?php echo __('Click here', 'wp-sukellos-fw'); ?>&lt;/a&gt;
            </div>

            <h3><?php echo __('Dynamic Parameter Enrichment', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('You can also add dynamic parameters to the tracking link, such as the recipient\'s email and name.', 'wp-sukellos-fw'); ?></p>

            <div class="code-block">
                https://yourdomain.com/wp-json/suket/link_click/?token=UNIQUE_TOKEN&amp;email=first.last@mydomain.com&amp;name=Doe
            </div>

            <h3><?php echo __('Using Merge Fields for Bulk Emails', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('Many bulk email tools, such as Zoho Bigin, support merge fields, which allow you to dynamically insert recipient-specific information into the tracking links. This automates the process of adding email and name parameters for each recipient.', 'wp-sukellos-fw'); ?></p>

            <p><strong><?php echo __('Example with Zoho Bigin:', 'wp-sukellos-fw'); ?></strong></p>
            <div class="code-block">
                https://yourdomain.com/wp-json/suket/link_click/?token=UNIQUE_TOKEN&amp;email=${MyEmailTemplate.E-mail}&amp;name=${MyEmailTemplate.Name}
            </div>

            <h2><?php echo __('Possible Use Cases', 'wp-sukellos-fw'); ?></h2>

            <h3><?php echo __('In an email campaign:', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('Use the tracking link in your email newsletters to track which recipients open the emails and click on links. The plugin provides personalized insights by using merge fields for email and name.', 'wp-sukellos-fw'); ?></p>

            <h3><?php echo __('On social media posts:', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('Use the tracking link on social media platforms like Twitter, Facebook, or LinkedIn to track engagement with links in your posts.', 'wp-sukellos-fw'); ?></p>

            <h3><?php echo __('In marketing materials on your website:', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('Place the tracking links on your website to monitor visitor behavior, track specific calls to action, and see which parts of your site are driving traffic.', 'wp-sukellos-fw'); ?></p>

            <h3><?php echo __('For affiliate marketing:', 'wp-sukellos-fw'); ?></h3>
            <p><?php echo __('Track the performance of affiliate links shared by your partners using your plugin-generated links.', 'wp-sukellos-fw'); ?></p>

            <div class="footer">
                <p><?php echo __('With this plugin, you can seamlessly track both email opens and link clicks. By incorporating merge fields, you can gain deeper insights into individual user engagement, making it ideal for businesses, marketers, and anyone running targeted email campaigns.', 'wp-sukellos-fw'); ?></p>
            </div>
        </div>


        <?php
        $html_content = ob_get_clean();

        $admin_page->create_content(
            array(
                'id' => $options_suffix_param.'_tracking_url_presentation_content',
                'name' => 'Détail de l\'élément',
                'content' => $html_content,
            )
        );
    }

}