<?php

namespace Sukellos\Admin;

use Sukellos\Email_Tracked_Url_List_Table;
use Sukellos\Email_Tracker_Url_Manager;
use Sukellos\WP_Email_Opens_Dao;
use Sukellos\WP_Link_Clicks_Dao;
use Sukellos\WP_Sukellos_Email_Tracker_Loader;
use Sukellos\WP_Tracked_Urls_Dao;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\Singleton;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 *
 * @since 1.0.0
 */
class WP_Sukellos_Email_Tracked_Url_Detail_Admin extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();
    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */

    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {}

    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items() {

        // To improve code readability
        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();
        WP_Log::debug( __METHOD__, ['$options_suffix_param'=>$options_suffix_param, 'GET' => $_GET], 'wp-sukellos-fw');

        // Admin page.
        $page_id = $options_suffix_param.'_email_tracked_url_detail_admin_page';

        if ( array_key_exists( 'page', $_GET ) && ( $_GET[ 'page' ] !== $page_id ) ) {

            WP_Log::debug( __METHOD__.' - Page is not '.$page_id, ['GET' => $_GET], 'wp-sukellos-fw' );
            return;
        }

        if ( !array_key_exists( 'id', $_GET ) ) {

            WP_Log::debug( __METHOD__.' - id is not defined', ['GET' => $_GET], 'wp-sukellos-fw' );
            return;
        }

        //
        // Page creation
        //
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => __( 'Tracked URL', 'wp-sukellos-fw' ),
                'title' => __( 'Tracked URL', 'wp-sukellos-fw' ),
                'id' => $page_id, // Unique ID of the menu item
                'capability' => 'manage_options', // User role
                'parent_id' => $options_suffix_param.'_email_tracked_urls_admin_page', // id of parent, if null, then this is a top level menu
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 100, // Menu position. Can be used for both top and sub level menus
                'use_tabs' => false,
                'desc' => __( 'Detail for a tracked URL', 'wp-sukellos-fw' )
            )
        );

        $html_retour = '<p><a href="'.get_site_url().'/wp-admin/admin.php?page='.$options_suffix_param.'_email_tracked_urls_admin_page">'.__( 'Back', 'wp-sukellos-fw' ).'</a></p>';

        // Load tracked URL
        $tracked_url = WP_Tracked_Urls_Dao::instance()->get_tracked_url( $_GET[ 'id' ] );
        WP_Log::debug( __METHOD__, ['$tracked_url'=>$tracked_url], 'wp-sukellos-fw');

        if ( is_null( $tracked_url ) ) {

            $html_retour .= '<p>'.__( 'Tracked URL not found', 'wp-sukellos-fw' ).'</p>';
        } else {

            $token = $tracked_url['token'];

            // Get link
            $tracking_link = Email_Tracker_Url_Manager::instance()->get_link_click_tracking_url( $token, false );
            $tracking_link_eg_zoho = Email_Tracker_Url_Manager::instance()->get_link_click_tracking_url( $token, true );
            $tracking_link_eg_manual = $tracking_link.'&email=first.last@mydomain.com&name=Doe';
            $tracking_link = Email_Tracker_Url_Manager::instance()->get_link_click_tracking_url( $token, false );
            $tracking_open_mail = Email_Tracker_Url_Manager::instance()->get_email_open_tracking_image( $token );

            // Get stats
            $total_emails_sent = $tracked_url['emails_sent'];
            $total_emails_opened = WP_Email_Opens_Dao::instance()->get_email_open_count_by_token( $token );
            $total_links_clicked = WP_Link_Clicks_Dao::instance()->get_link_click_count_by_token( $token );
            WP_Log::debug( __METHOD__, ['$total_emails_sent'=>$total_emails_sent], 'wp-sukellos-fw');

            // Calculate %
            $emails_opened_rate = '-';
            $links_clicked_emails_opened_rate = '-';
            $links_clicked_total_emails_sent_rate = '-';
            if ( ( $total_emails_sent > 0 ) && ( $total_emails_opened > 0 ) ) {

                $emails_opened_rate = round( $total_emails_opened/$total_emails_sent, 4 ) * 100;
                $links_clicked_emails_opened_rate = round( $total_links_clicked/$total_emails_opened, 4 ) * 100;
                $links_clicked_total_emails_sent_rate = round( $total_links_clicked/$total_emails_sent, 4 ) * 100;
            }

            $html_retour .= '
                <div class="url-tracked-container">
                                
                    <div class="tracked-url">
                        <h2>'.$tracked_url['name'].'</h2>
                            <p><strong>'.__( 'Target URL:', 'wp-sukellos-fw' ).'</strong></p>
                            <p>'.$tracked_url['url_target'].'</p>
                            <p><strong>'.__( 'Desscription:', 'wp-sukellos-fw' ).'</strong></p>
                            <p>'.$tracked_url['description'].'</p>
                    </div>
                        
                    <div class="tracking-info">
                    
                        <!-- Prelude: Token link and tracking image -->
                        <div class="prelude">
                            <h2>'.__( 'Email open tracking', 'wp-sukellos-fw' ).'</h2>
                            <p><strong>'.__( 'Tracking image for email open:', 'wp-sukellos-fw' ).'</strong></p>
                            <div class="code-block">
                                '.htmlspecialchars( $tracking_open_mail ).'
                            </div>
                            <p>'.__( 'This HTML code can be inserted into the body of the email, for example at the end, to track email opens.', 'wp-sukellos-fw' ).'</p>
                            <p>'.__( 'You should know that an image of this type, also known as a tracking pixel, is easily detectable by common email tools. A future version of this extension will address this issue by generating a tracking link from an existing image embedded in the email, such as a logo, for example.', 'wp-sukellos-fw' ).'</p>
                        </div>
                        <div class="prelude">
                            <h2>'.__( 'Link visit tracking', 'wp-sukellos-fw' ).'</h2>
                            <p><strong>'.__( 'Tracking link:', 'wp-sukellos-fw' ).'</strong></p>
                            <div class="code-block">
                                '.$tracking_link.'
                            </div>
                            <p>'.__( 'This tracking link must be used instead of the target URL to count the visits to the latter...', 'wp-sukellos-fw' ).'</p>
                            <p>'.__( 'It is possible to add an <strong>email</strong> and <strong>name</strong> parameters to this link in order to refine the collected statistics.', 'wp-sukellos-fw' ).'</p>
                            <p><strong>'.__( 'Example of a link with manual addition of an email and a name', 'wp-sukellos-fw' ).'</strong></p>
                            <div class="code-block">
                                '.$tracking_link_eg_manual.'
                            </div>
                            <p>'.__( 'Some ERPs offer bulk email sending with automatic population of these fields.', 'wp-sukellos-fw' ).'</p>
                            <p><strong>'.__( 'Example of a link with the addition of an email and name template for bulk emails in Zoho Bigin', 'wp-sukellos-fw' ).'</strong></p>
                            <div class="code-block">
                                '.$tracking_link_eg_zoho.'
                            </div>
                        </div>
                    </div>
                
                    <div class="stats">
                        <h2>'.__( 'Tracking Statistics', 'wp-sukellos-fw' ).'</h2>
                
                        <h3>'.__( 'Totals', 'wp-sukellos-fw' ).'</h3>
                        <div class="stat-items">
                            <div class="stat-item">
                                <span>'.$total_emails_sent.'</span> 
                                <p>'.__( 'Total Emails Sent', 'wp-sukellos-fw' ).'</p>
                            </div>
                            <div class="stat-item">
                                <span>'.$total_emails_opened.'</span> 
                                <p>'.__( 'Total Emails Opened', 'wp-sukellos-fw' ).'</p>
                            </div>
                            <div class="stat-item">
                                <span>'.$total_links_clicked.'</span> 
                                <p>'.__( 'Total Links Clicked', 'wp-sukellos-fw' ).'</p>
                            </div>
                        </div>
                
                        <h3>'.__( 'Conversion Rates', 'wp-sukellos-fw' ).'</h3>
                        <div class="conversion-rates">
                            <div class="rate-box">
                                <span>'.$emails_opened_rate.'%</span> 
                                <p>'.__( 'Emails Opened', 'wp-sukellos-fw' ).'</p>
                            </div>
                            <div class="rate-box">
                                <span>'.$links_clicked_emails_opened_rate.'%</span> 
                                <p>'.__( 'Links Clicked / Emails Opened', 'wp-sukellos-fw' ).'</p>
                            </div>
                            <div class="rate-box">
                                <span>'.$links_clicked_total_emails_sent_rate.'%</span> 
                                <p>'.__( 'Links Clicked / Total Emails Sent', 'wp-sukellos-fw' ).'</p>
                            </div>
                        </div>
                    </div>
                    <div class="tracking-details">
                ';

            // Tracking detail
            // COMPLETE
            list( $url_target, $emails_sent, $grouped_data ) = Email_Tracker_Url_Manager::instance()->get_tracking_data_by_token( $token );

            if ( is_null( $url_target ) ) {

                $html_retour .= '<p>'.__( 'No tracking data found for this token.', 'wp-sukellos-fw' ).'</p>';
            }
            else {

                $html_retour .= '
                    <h2>'.__( 'Tracking Summary for Token', 'wp-sukellos-fw' ).'</h2>
                    
                    <p><strong>'.__( 'Target URL:', 'wp-sukellos-fw' ).'</strong> '.esc_html( $url_target).'</p>
                    <p><strong>'.__( 'Total Emails Sent:', 'wp-sukellos-fw' ).'</strong> '.esc_html( $emails_sent ).'</p>
                    
                    <table border="1" cellpadding="10" cellspacing="0" style="width:100%; border-collapse:collapse;">
                        <thead>
                        <tr>
                            <th>'.__( 'Email', 'wp-sukellos-fw' ).'</th><th>'.__( 'Name', 'wp-sukellos-fw' ).'</th><th>'.__( 'IP Address', 'wp-sukellos-fw' ).'</th><th>'.__( 'User-Agent', 'wp-sukellos-fw' ).'</th><th>'.__( 'Emails Opened', 'wp-sukellos-fw' ).'</th><th>'.__( 'Links Clicked', 'wp-sukellos-fw' ).'</th>
                        </tr>
                        </thead>
                        <tbody>
                ';

                // Parcourir les données groupées
                foreach ( $grouped_data as $row ) {

                    $html_retour .= '
                    <tr>
                        <td>'.esc_html( $row[ 'email' ] ).'</td>
                        <td>'.esc_html( $row[ 'name' ] ).'</td>
                        <td>'.esc_html( $row[ 'ip_address' ] ).'</td>
                        <td>'.esc_html( $row[ 'user_agent' ] ).'</td>
                        <td>'.esc_html( $row[ 'emails_opened' ] ).'</td>
                        <td>'.esc_html( $row[ 'links_clicked' ] ).'</td>
                    </tr>
                    ';
                }

                $html_retour .= '</tbody></table>';
            }
            $html_retour .= '</div></div>';
        }

        $admin_page->create_content(
            array(
                'id' => $options_suffix_param.'_tracked_url_detail_content',
                'name' => 'Détail de l\'élément',
                'content' => $html_retour,
            )
        );
    }

}