<?php

namespace Sukellos\Admin;

use Sukellos\Email_Tracked_Url_List_Table;
use Sukellos\Email_Tracker_Url_Manager;
use Sukellos\WP_Email_Opens_Dao;
use Sukellos\WP_Link_Clicks_Dao;
use Sukellos\WP_Sukellos_Email_Tracker_Loader;
use Sukellos\WP_Tracked_Urls_Dao;
use Sukellos\WPFw\AdminBuilder\Item_Type;
use Sukellos\WPFw\Utils\WP_Log;
use Sukellos\WPFw\WP_Plugin_Admin;
use Sukellos\WPFw\AdminBuilder\Admin_Builder;
use Sukellos\WPFw\Singleton;

defined( 'ABSPATH' ) or exit;

/**
 * Admin class.
 *
 * @since 1.0.0
 */
class WP_Sukellos_Email_Tracked_Url_Edit_Admin extends WP_Plugin_Admin {

    // Use Trait Singleton
    use Singleton;

    /**
     * Default init method called when instance created
     * This method can be overridden if needed.
     *
     * @since 1.0.0
     * @access protected
     */
    public function init() {

        parent::init();

        /**
         * Action : sukellos_fw/admin_builder/item_form/fields_submitted_{form_item_id}
         * Called after the fields are submitted only if mandatories verified in form item
         */
        add_action( 'sukellos_fw/admin_builder/item_form/fields_submitted_'.WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param().'_form_edit_tracked_url', array( $this, 'action_item_form_fields_submitted' ) );

    }

    /**
     * Process the form submitted on itself
     * @return string the notice
     */
    public function action_item_form_fields_submitted() {

        WP_Log::debug( __METHOD__, ['POST'=>$_POST], 'wp-sukellos-fw');

        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();

        $tracked_url_id = $_POST[ $options_suffix_param.'_tracked_url_id' ];
        $number_emails_sent = $_POST[ $options_suffix_param . '_edit_number_emails_sent' ];
        $description = $_POST[ $options_suffix_param . '_edit_description' ];

        // Add tracking
        WP_Tracked_Urls_Dao::instance()->update_emails_sent( $tracked_url_id, $number_emails_sent );
        WP_Tracked_Urls_Dao::instance()->update_description( $tracked_url_id, $description );
    }

    /**
     *          ===============
     *      =======================
     *  ============ HOOKS ===========
     *      =======================
     *          ===============
     */

    /***
     * Adding CSS and JS into header
     * Default add assets/admin.css and assets/admin.js
     */
    public function admin_enqueue_scripts() {}

    /***
     * Admin page
     * Settings managed by main Sukellos Fw Tools admin
     */
    public function create_items() {

        // To improve code readability
        $options_suffix_param = WP_Sukellos_Email_Tracker_Loader::instance()->get_options_suffix_param();
        WP_Log::debug( __METHOD__, ['$options_suffix_param'=>$options_suffix_param, 'GET' => $_GET], 'wp-sukellos-fw');

        // Admin page.
        $page_id = $options_suffix_param.'_edit_email_tracked_url_admin_page';

        if ( array_key_exists( 'page', $_GET ) && ( $_GET[ 'page' ] !== $page_id ) ) {

            WP_Log::debug( __METHOD__.' - Page is not '.$page_id, ['GET' => $_GET], 'wp-sukellos-fw' );
            return;
        }

        if ( !array_key_exists( 'id', $_GET ) ) {

            WP_Log::debug( __METHOD__.' - id is not defined', ['GET' => $_GET], 'wp-sukellos-fw' );
            return;
        }

        $tracked_url_id = $_GET[ 'id' ];

        //
        // Page creation
        //
        $admin_page = Admin_Builder::instance()->create_admin_page(
            array(
                'name' => __( 'Edit tracked URL', 'wp-sukellos-fw' ),
                'title' => __( 'Edit tracked URL', 'wp-sukellos-fw' ),
                'id' => $page_id, // Unique ID of the menu item
                'capability' => 'manage_options', // User role
                'parent_id' => $options_suffix_param.'_email_tracked_urls_admin_page', // id of parent, if null, then this is a top level menu
                'icon' => 'dashicons-smiley', // Menu icon for top level menus only https://developer.wordpress.org/resource/dashicons/#editor-paste-word
                'position' => 100, // Menu position. Can be used for both top and sub level menus
                'use_tabs' => false,
                'desc' => __( 'Allow to edit tracked URL', 'wp-sukellos-fw' )
            )
        );

        $html_retour = '<p><a href="'.get_site_url().'/wp-admin/admin.php?page='.$options_suffix_param.'_email_tracked_urls_admin_page">'.__( 'Back', 'wp-sukellos-fw' ).'</a></p>';

        // Load tracked URL
        $tracked_url = WP_Tracked_Urls_Dao::instance()->get_tracked_url( $tracked_url_id );
        WP_Log::debug( __METHOD__, ['$tracked_url'=>$tracked_url], 'wp-sukellos-fw');

        if ( is_null( $tracked_url ) ) {

            $html_retour .= '<p>'.__( 'Tracked URL not found', 'wp-sukellos-fw' ).'</p>';
            $admin_page->create_content(
                array(
                    'id' => $options_suffix_param.'_email_tracked_url_edit_content',
                    'name' => 'Détail de l\'élément',
                    'content' => $html_retour,
                )
            );
        } else {

            $admin_page->create_content(
                array(
                    'id' => $options_suffix_param.'_email_tracked_url_edit_content',
                    'name' => 'Détail de l\'élément',
                    'content' => $html_retour,
                )
            );

            // Create a form
            $form = $admin_page->create_form(
                array(
                    'id' => $options_suffix_param . '_form_edit_tracked_url',
                    'name' => __( 'Form used to edit tracked URL', 'wp-sukellos-fw' ),
                    'desc' =>__( 'Form used to edit tracked URL', 'wp-sukellos-fw' ),
                    'use_reset' => false,
                    'save' => __( 'Edit', 'wp-sukellos-fw' ),
                )
            );

            // Create a URL  field
            $field = $form->create_form_field(
                array(
                    'type' => Item_type::TEXTAREA,
                    'id' => $options_suffix_param.'_edit_description',
                    'name' => __( 'Description', 'wp-sukellos-fw' ),
                    'desc' => __( 'Description of the campaign.', 'wp-sukellos-fw' ),
                    'default' => '',
                    'hidden' => false,
                )
            );
            $field->set_value( $tracked_url[ 'description' ] );


            // Create a URL  field
            $field = $form->create_form_field(
                array(
                    'type' => Item_type::NUMBER,
                    'id' => $options_suffix_param . '_edit_number_emails_sent',
                    'name' => 'Number',
                    'desc' => __( 'Estimated number of emails to be sent containing the tracked URL.', 'wp-sukellos-fw' ),
                    'default' => 0,
                    'css' => '',
                    'hidden' => false,
                    // Specific
                    'size' => 'medium', // or medium or large
                    'placeholder' => '', // show this when blank
                    'min' => 0, // Minimum value, default 0
                    'max' => 1000000, // Maximum value, default 1000
                    'step' => 1, // Step, default 1
                    'unit' => 'emails', // Unit, added after the slider for information, default ''
                )
            );
            $field->set_value( $tracked_url[ 'emails_sent' ] );

            // Create a textarea option field
            $field = $form->create_form_field(
                array(
                    'type' => Item_type::TEXT,
                    // Common
                    'id' => $options_suffix_param.'_tracked_url_id',
                    'name' => __( 'Tracked URL', 'wp-sukellos-fw' ),
                    'desc' => '',
                    'default' => $tracked_url[ 'id' ],
                    'hidden' => true,
                )
            );
            $field->set_value( $tracked_url[ 'id' ] );
        }

    }

}