<?php

namespace Sukellos;

use Sukellos\WPFw\Singleton;
use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * This class is used to CRUD email opens from DB
 * Managed tables :
 * suk_et_email_opens
 *
 * @since 1.0.0
 */
class WP_Email_Opens_Dao {

    // Use Trait Singleton
    use Singleton;

    /**
     * Insert an email open
     * @param $tracked_url_id
     * @param $token
     * @param $ip_address
     * @param $user_agent
     * @return int
     */
    public function insert_email_open( $tracked_url_id, $token, $ip_address, $user_agent ) {

        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_email_opens';

        $wpdb->insert(
            $table_name,
            array(
                'tracked_url_id' => $tracked_url_id,
                'token' => $token,
                'opened_at' => current_time( 'mysql' ),
                'ip_address' => $ip_address,
                'user_agent' => $user_agent
            ),
            array( '%d', '%s', '%s', '%s', '%s' )
        );

        return $wpdb->insert_id;
    }

    /**
     * Get the open mail count by token
     * @param $token
     * @return string|null
     */
    public function get_email_open_count_by_token( $token ) {

        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_email_opens';

        $query = $wpdb->prepare(
            "SELECT COUNT(*) FROM $table_name WHERE token = %s",
            $token
        );

        return $wpdb->get_var( $query );
    }


    /**
     * Get a email open by token
     * @param $token
     * @return array|object|\stdClass[]|null
     */
    public function get_email_opens_by_token( $token ) {
        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_email_opens';

        $query = $wpdb->prepare(
            "SELECT * FROM $table_name WHERE token = %s",
            $token
        );

        return $wpdb->get_results( $query );
    }

    /**
     * Get a email open
     * @param $token
     * @return array|object|\stdClass[]|null
     */
    public function get_email_opens( $id ) {
        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_email_opens';

        $query = $wpdb->prepare(
            "SELECT * FROM $table_name WHERE id = %d",
            $id
        );

        return $wpdb->get_results( $query );
    }

    /**
     * Delete a emil open by tracked url
     * @param $token
     * @return bool|int|\mysqli_result|null
     */
    public function delete_email_opens_by_tracked_url( $tracked_url_id ) {
        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_email_opens';

        return $wpdb->delete( $table_name, array( 'tracked_url_id' => $tracked_url_id ), array( '%d' ) );
    }

    /**
     * Delete a emil open by token
     * @param $token
     * @return bool|int|\mysqli_result|null
     */
    public function delete_email_opens_by_token( $token ) {
        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_email_opens';

        return $wpdb->delete( $table_name, array( 'token' => $token ), array( '%s' ) );
    }

    /**
     * Delete a emil open
     * @param $id
     * @return bool|int|\mysqli_result|null
     */
    public function delete_email_opens( $id ) {
        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_email_opens';

        return $wpdb->delete( $table_name, array( 'id' => $id ), array( '%d' ) );
    }

}