<?php

namespace Sukellos;

use Sukellos\WPFw\Singleton;
use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * This class is used to CRUD link clicks from DB
 * Managed tables :
 * suk_et_link_clicks
 *
 * @since 1.0.0
 */
class WP_Link_Clicks_Dao {

    // Use Trait Singleton
    use Singleton;

    /**
     * Insert a link click
     * @param $tracked_url_id
     * @param $token
     * @param $email
     * @param $name
     * @param $ip_address
     * @param $user_agent
     * @return int
     */
    public function insert_link_click($tracked_url_id, $token, $email, $name, $ip_address, $user_agent) {

        global $wpdb;
        $table_name = $wpdb->prefix . 'suk_et_link_clicks';

        $wpdb->insert(
            $table_name,
            array(
                'tracked_url_id' => $tracked_url_id,
                'token' => $token,
                'email' => $email,
                'name' => $name,
                'clicked_at' => current_time('mysql'),
                'ip_address' => $ip_address,
                'user_agent' => $user_agent
            ),
            array('%d', '%s', '%s', '%s', '%s', '%s', '%s')
        );

        return $wpdb->insert_id; // Retourne l'ID inséré
    }

    /**
     * Get the number of link clicks by token
     * @param $token
     * @return string|null
     */
    public function get_link_click_count_by_token( $token ) {
        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_link_clicks';

        $query = $wpdb->prepare(
            "SELECT COUNT(*) FROM $table_name WHERE token = %s",
            $token
        );

        return $wpdb->get_var( $query ); // Retourne le nombre de clics sur le lien
    }


    /**
     * Get a link click by tken
     * @param $token
     * @return array|object|\stdClass[]|null
     */
    public function get_link_clicks_by_token( $token ) {

        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_link_clicks';

        $query = $wpdb->prepare(
            "SELECT * FROM $table_name WHERE token = %s",
            $token
        );

        return $wpdb->get_results( $query ); // Retourne un tableau d'objets avec les résultats
    }

    /**
     * Get a link click
     * @param $id
     * @return array|object|\stdClass[]|null
     */
    public function get_link_clicks( $id ) {

        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_link_clicks';

        $query = $wpdb->prepare(
            "SELECT * FROM $table_name WHERE id = %d",
            $id
        );

        return $wpdb->get_results( $query ); // Retourne un tableau d'objets avec les résultats
    }

    /**
     * Delete a link click by tracked url
     * @param $token
     * @return bool|int|\mysqli_result|null
     */
    public function delete_link_clicks_by_tracked_url( $tracked_url_id ) {

        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_link_clicks';

        return $wpdb->delete( $table_name, array( 'tracked_url_id' => $tracked_url_id ), array( '%d' ) );
    }

    /**
     * Delete a link click by token
     * @param $token
     * @return bool|int|\mysqli_result|null
     */
    public function delete_link_clicks_by_token( $token ) {

        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_link_clicks';

        return $wpdb->delete( $table_name, array( 'token' => $token ), array( '%s' ) );
    }

    /**
     * Delete a link click
     * @param $id
     * @return bool|int|\mysqli_result|null
     */
    public function delete_link_clicks( $id ) {

        global $wpdb;
        $table_name = $wpdb->prefix.'suk_et_link_clicks';

        return $wpdb->delete( $table_name, array( 'id' => $id ), array( '%d' ) );
    }


}