<?php

namespace Sukellos\WPFw\AdminBuilder\Fields;

use Sukellos\WPFw\Utils\WP_Log;

defined( 'ABSPATH' ) or exit;

/**
 * Handler for form field
 *
 * Allow polymorphism
 *
 * @since 1.3.0
 */
class Form_Field_Handler extends Field_Handler {

    /**
     * Constructor
     *
     * @param $default default value
     */
    public function __construct( $field_id, $default ) {

        $this->field_id = $field_id;
        $this->default = $default;
    }

    /**
     * Save field value depending of its specific type
     */
    public function save() {

        WP_Log::debug( __METHOD__, ['POST'=>$_POST, 'field_id'=>$this->field_id]);

        if ( isset( $_POST[ ''.$this->field_id ] ) ) {

            $_SESSION[ ''.$this->field_id ] = $_POST[ ''.$this->field_id ];
        }
        return true;
    }

    /**
     * Load field value depending of its specific type
     */
    public function load() {

        WP_Log::debug( __METHOD__, ['POST'=>$_POST, 'field_id'=>$this->field_id, 'default'=>$this->default]);

        if ( !is_null( $this->get_value() ) ) {

            // DOes nothing
        }
        // Get it from POST
        else if ( isset( $_POST[ ''.$this->field_id ] ) && !empty($_POST[ ''.$this->field_id ]) ) {

            $this->set_value( $_POST[ ''.$this->field_id ] );
        }
        else if ( isset( $_SESSION[ ''.$this->field_id ] ) ) {

            $this->set_value( $_SESSION[ ''.$this->field_id ] );
        } else {

            $this->set_value( $this->default );
        }

        WP_Log::debug( __METHOD__, ['field_id'=>$this->field_id, 'value loaded'=>$this->value]);
        return $this->value;
    }

    /**
     * Reset field value depending of its specific type
     */
    public function reset() {

        WP_Log::debug( 'Option_Handler->save', ['POST'=>$_POST]);

        // Verify that this is the good field id
        // Then value is contained in POST request
        if ( isset( $_POST[ ''.$this->field_id ] ) ) {

            $this->set_value( $this->default );

            return true;
        }

        return false;
    }
}
